@@ -65,6 +65,8 @@ class Notice(object):
         "Creates a notice from an exception"
         if exc_info is None:
             exc_info = sys.exc_info()
+            if exc_info[1] is None:
+                raise ValueError("exc_info is required outside of an exception handler")
         exc_type, exc_value, exc_tb = exc_info
         return cls(config, *exc_info)
 
@@ -84,6 +86,8 @@ class Notice(object):
         ET.SubElement(error, 'message').text = self.error_message
         backtrace = ET.SubElement(error, 'backtrace')
         for filename, line_number, function_name, text in reversed(self.backtrace):
+            if filename.startswith(self.config.project_root):
+                filename = "[PROJECT_ROOT]/" + filename[len(self.config.project_root):]
             ET.SubElement(
                 backtrace, 'line', number=str(line_number), file=filename, method=function_name)
 
